@@ -7,10 +7,11 @@
 #' @return A tibble with data items.
 #'
 #' @note An internet connection is required. The MARC 21 field
-#' definitions are used.
+#' definitions are used. This function does not currently work
+#' due to changes to the VIAF.
 #'
 #' @examples
-#' \donttest{viaf_get(c("64013650", "102333412"))}
+#' \dontrun{viaf_get(c("64013650", "102333412"))}
 #'
 #' @importFrom purrr map
 #' @importFrom magrittr "%>%"
@@ -18,6 +19,11 @@
 #' @rdname get
 #' @export
 viaf_get <- function(query = NULL, ...) {
+  stop(
+    "This function does not currently work ",
+    "due to changes to the VIAF."
+  )
+
   if (is.null(query)) {
     stop("VIAF query could not be parsed.")
   }
@@ -30,7 +36,8 @@ viaf_get <- function(query = NULL, ...) {
   }
 
   items <- map(query, viaf_retrieve, ...) %>%
-    map(get_identifier) %>% dplyr::bind_rows()
+    map(get_identifier) %>%
+    dplyr::bind_rows()
 
   return(items)
 }
@@ -41,17 +48,17 @@ get_identifier <- function(x) {
   if (is.null(x)) {
     return(
       tibble(
-        viaf_id = NA, source_ids = list(),
-        name_type = NA, text = list()
+        viaf_id = NA,
+        source_ids = list(),
+        name_type = NA,
+        text = list()
       )
     )
   }
 
   metadata <- tibble(
-    viaf_id = x$viafID, source_ids = list(
-      get_source_ids(x$sources$source)
-    ),
-
+    viaf_id = x$viafID,
+    source_ids = list(get_source_ids(x$sources$source)),
     name_type = get_name_type(x$nameType)[[1]],
     text = list(get_text(x))
   )
